searchNodes=[{"doc":"An Elixir utility for calculating the following color combinations: Complimentary - Two colors that are on opposite sides of the color wheel Analagous - Three colors that are side by side on the color wheel Monochromatic - A spectrum of shades, tones and tints of one base color Triadic - Three colors that are evenly spaced on the color wheel Tetradic - Four colors that are evenly spaced on the color wheel","ref":"MotleyHue.html","title":"MotleyHue","type":"module"},{"doc":"Returns the provided color and its two analagous (adjacent) colors along a given direction of the HSV color wheel. Adjacency is defined by a 30° offset in hue value and an analogous set must reside within a 90° section of the color wheel. Examples iex&gt; MotleyHue . analagous ( &quot;FF0000&quot; ) [ &quot;FF0000&quot; , &quot;FF8000&quot; , &quot;FFFF00&quot; ] iex&gt; MotleyHue . analagous ( &quot;FF0000&quot; , :counter_clockwise ) [ &quot;FF0000&quot; , &quot;FF0080&quot; , &quot;FF00FF&quot; ]","ref":"MotleyHue.html#analagous/2","title":"MotleyHue.analagous/2","type":"function"},{"doc":"Returns the provided color and its compliment. Note that complimentary color can be calculated by either taking the value 180° (i.e., opposite) from the hue value on the HSV color wheel or by finding the RGB value that when combined with the provided color will yield white (i.e., rgb(255, 255, 255)). The default approach is to use the HSV hue offset, but either can be calculated by passing :hsv or :rgb as the model argument. Examples iex&gt; MotleyHue . complimentary ( &quot;FF0000&quot; ) [ &quot;FF0000&quot; , &quot;00FFFF&quot; ] iex&gt; MotleyHue . complimentary ( &quot;008080&quot; , :hsv ) [ &quot;008080&quot; , &quot;800000&quot; ] iex&gt; MotleyHue . complimentary ( &quot;008080&quot; , :rgb ) [ &quot;008080&quot; , &quot;FF7F7F&quot; ]","ref":"MotleyHue.html#complimentary/2","title":"MotleyHue.complimentary/2","type":"function"},{"doc":"Returns the requested count of colors, including the provided color, distributed along the color wheel. Ideal for use as color palette where adjacent colors need to be easily differentiated with one another (e.g., categorical or other non-quantitative data). Examples iex&gt; MotleyHue . contrast ( &quot;FF0000&quot; , 7 ) [ &quot;FF0000&quot; , &quot;FFFF00&quot; , &quot;00FF00&quot; , &quot;00FFFF&quot; , &quot;0000FF&quot; , &quot;FF00FF&quot; , &quot;FF8000&quot; ] iex&gt; MotleyHue . contrast ( &quot;FF0000&quot; , 13 ) [ &quot;FF0000&quot; , &quot;FFFF00&quot; , &quot;00FF00&quot; , &quot;00FFFF&quot; , &quot;0000FF&quot; , &quot;FF00FF&quot; , &quot;FF8000&quot; , &quot;80FF00&quot; , &quot;00FF80&quot; , &quot;0080FF&quot; , &quot;8000FF&quot; , &quot;FF0080&quot; , &quot;FF4000&quot; ]","ref":"MotleyHue.html#contrast/2","title":"MotleyHue.contrast/2","type":"function"},{"doc":"Returns the requested count of colors, including the provided color, evenly spaced along the color wheel. Examples iex&gt; MotleyHue . even ( &quot;FF0000&quot; , 5 ) [ &quot;FF0000&quot; , &quot;CCFF00&quot; , &quot;00FF66&quot; , &quot;0066FF&quot; , &quot;CC00FF&quot; ]","ref":"MotleyHue.html#even/2","title":"MotleyHue.even/2","type":"function"},{"doc":"Returns the provided color and its monochromatic color spectrum towards black. The number of results is configurable with each color equally spaced from the previous value. Examples iex&gt; MotleyHue . monochromatic ( &quot;FF0000&quot; ) [ &quot;FF0000&quot; , &quot;AB0000&quot; , &quot;570000&quot; ] iex&gt; MotleyHue . monochromatic ( &quot;FF0000&quot; , 5 ) [ &quot;FF0000&quot; , &quot;CC0000&quot; , &quot;990000&quot; , &quot;660000&quot; , &quot;330000&quot; ]","ref":"MotleyHue.html#monochromatic/2","title":"MotleyHue.monochromatic/2","type":"function"},{"doc":"Returns the provided color and its three tetradic colors, which are the colors 90°, 180°, and 270° offset from the given color's hue value on the HSV color wheel. Examples iex&gt; MotleyHue . tetradic ( &quot;FF0000&quot; ) [ &quot;FF0000&quot; , &quot;80FF00&quot; , &quot;00FFFF&quot; , &quot;8000FF&quot; ]","ref":"MotleyHue.html#tetradic/1","title":"MotleyHue.tetradic/1","type":"function"},{"doc":"Returns the provided color and its two triadic colors, which are the colors 120° and 240° offset from the given color's hue value on the HSV color wheel. Examples iex&gt; MotleyHue . triadic ( &quot;FF0000&quot; ) [ &quot;FF0000&quot; , &quot;00FF00&quot; , &quot;0000FF&quot; ]","ref":"MotleyHue.html#triadic/1","title":"MotleyHue.triadic/1","type":"function"},{"doc":"Mötley Hüe is a small library built on top of Chameleon for calculating color combinations. All color conversion is delegated to Chameleon while Mötley Hüe simply handles the math to determine the following combinations for a given color: Complimentary - Two colors that are on opposite sides of the color wheel Analagous - Three colors that are side by side on the color wheel Monochromatic - A spectrum of shades, tones and tints of one base color Triadic - Three colors that are evenly spaced on the color wheel Tetradic - Four colors that are evenly spaced on the color wheel Even - An arbitrary number of colors that are evenly spaced on the color wheel Contrast - An arbitrary number of colors that are distributed around the color wheel for maximum sequential differentiation","ref":"readme.html","title":"Mötley Hüe","type":"extras"},{"doc":"If available in Hex , the package can be installed by adding motley_hue to your list of dependencies in mix.exs : def deps do [ { :motley_hue , &quot;~&gt; 0.2&quot; } ] end","ref":"readme.html#installation","title":"Mötley Hüe - Installation","type":"extras"},{"doc":"While Mötley Hüe is compatible with any struct used in Chameleon, the simplest interface is through hexadecimal color codes. All results include the given color for ease of use as a ready-to-go color palette. iex&gt; MotleyHue . complimentary ( &quot;FF0000&quot; ) [ &quot;FF0000&quot; , &quot;00FFFF&quot; ] iex&gt; MotleyHue . analagous ( &quot;FF0000&quot; ) [ &quot;FF0000&quot; , &quot;FF8000&quot; , &quot;FFFF00&quot; ] iex&gt; MotleyHue . monochromatic ( &quot;FF0000&quot; ) [ &quot;FF0000&quot; , &quot;AB0000&quot; , &quot;570000&quot; ] iex&gt; MotleyHue . triadic ( &quot;FF0000&quot; ) [ &quot;FF0000&quot; , &quot;00FF00&quot; , &quot;0000FF&quot; ] iex&gt; MotleyHue . tetradic ( &quot;FF0000&quot; ) [ &quot;FF0000&quot; , &quot;80FF00&quot; , &quot;00FFFF&quot; , &quot;8000FF&quot; ] iex&gt; MotleyHue . even ( &quot;FF0000&quot; , 5 ) [ &quot;FF0000&quot; , &quot;CCFF00&quot; , &quot;00FF66&quot; , &quot;0066FF&quot; , &quot;CC00FF&quot; ] iex&gt; MotleyHue . contrast ( &quot;FF0000&quot; , 7 ) [ &quot;FF0000&quot; , &quot;FFFF00&quot; , &quot;00FF00&quot; , &quot;00FFFF&quot; , &quot;0000FF&quot; , &quot;FF00FF&quot; , &quot;FF8000&quot; ] If you're using Chameleon directly, then Mötley Hüe will return your color combinations with the same struct definition it was given. iex&gt; Chameleon.RGB . new ( 255 , 0 , 0 ) |&gt; MotleyHue . complimentary ( ) [ % Chameleon.RGB { b : 0 , g : 0 , r : 255 } , % Chameleon.RGB { b : 255 , g : 255 , r : 0 } ]","ref":"readme.html#use","title":"Mötley Hüe - Use","type":"extras"}]